@@ -1,131 +1,4 @@
 
-#' @name copyCalibrationCurve
-#' @title Copy a calibration curve.
-#' @description Copy one of the the calibration curves into memory.
-#' @details Copy the radiocarbon calibration curve defined by cc into memory.
-#' @return The calibration curve (invisible).
-#' @param cc Calibration curve for 14C dates: \code{cc=1} for IntCal20 (northern hemisphere terrestrial), \code{cc=2} for Marine20 (marine),
-#' \code{cc=3} for SHCal20 (southern hemisphere terrestrial).
-#' @param postbomb Use \code{postbomb=TRUE} to get a postbomb calibration curve (default \code{postbbomb=FALSE}).
-#' @author Maarten Blaauw, J. Andres Christen
-#' @examples
-#' intcal20 <- copyCalibrationCurve(1)
-#' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
-#' @export
-copyCalibrationCurve <- function(cc=1, postbomb=FALSE) {
-  if(postbomb) {
-    if(cc==1) fl <- "postbomb_NH1.14C" else
-      if(cc==2) fl <- "postbomb_NH2.14C" else
-        if(cc==3) fl <- "postbomb_NH3.14C" else
-          if(cc==4) fl <- "postbomb_SH1-2.14C" else
-            if(cc==5) fl <- "postbomb_SH3.14C" else
-              stop("calibration curve doesn't exist\n", call.=FALSE)
-  } else
-  if(cc==1) fl <- "3Col_intcal20.14C" else
-    if(cc==2) fl <- "3Col_marine20.14C" else
-      if(cc==3) fl <- "3Col_shcal20.14C" else
-        stop("calibration curve doesn't exist\n", call.=FALSE)
-  cc <- system.file("extdata/Curves", fl, package='rbacon')
-  cc <- read.table(cc)
-  invisible(cc)
-}
-
-
-
-#' @name mix.curves
-#' @title Build a custom-made, mixed calibration curve.
-#' @description If two curves need to be `mixed' to calibrate, e.g. for dates of mixed terrestrial and marine carbon sources, then this function can be used.
-#' @details The proportional contribution of each of both calibration curves has to be set.
-#'
-#' @param proportion Proportion of the first calibration curve required. e.g., change to \code{proportion=0.7} if \code{cc1} should contribute 70\% (and \code{cc2} 30\%) to the mixed curve.
-#' @param cc1 The first calibration curve to be mixed. Defaults to the northern hemisphere terrestrial curve IntCal20.
-#' @param cc2 The second calibration curve to be mixed. Defaults to the marine curve IntCal20.
-#' @param name Name of the new calibration curve.
-#' @param dirname Directory where the file will be written. If using the default \code{dirname="."},
-#' the new curve will be saved in current working directory.
-#' @param offset Any offset and error to be applied to \code{cc2} (default 0 +- 0).
-#' @param sep Separator between fields (tab by default, "\\t")
-#' @author Maarten Blaauw, J. Andres Christen
-#' @return A file containing the custom-made calibration curve, based on calibration curves \code{cc1} and \code{cc2}.
-#' @examples
-#' mix.curves(, dirname=tempdir())
-#' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
-#' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
-#' \url{https://projecteuclid.org/euclid.ba/1339616472}
-#' @export
-mix.curves <- function(proportion=.5, cc1="3Col_intcal20.14C", cc2="3Col_marine20.14C", name="mixed.14C", dirname=".", offset=c(0,0), sep="\t") {
-  ccloc <- paste0(system.file("extdata", package='rbacon'), "/Curves/")
-  dirname <- .validateDirectoryName(dirname)
-
-  cc1 <- read.table(paste(ccloc, cc1,  sep=""))
-  cc2 <- read.table(paste(ccloc, cc2,  sep=""))
-  cc2.mu <- approx(cc2[,1], cc2[,2], cc1[,1], rule=2)$y + offset[1] # interpolate cc2 to the calendar years of cc1
-  cc2.error <- approx(cc2[,1], cc2[,3], cc1[,1], rule=2)$y
-  cc2.error <- sqrt(cc2.error^2 + offset[2]^2)
-  mu <- proportion * cc1[,2] + (1-proportion) * cc2.mu
-  error <- proportion * cc1[,3] + (1-proportion) * cc2.error
-  write.table(cbind(cc1[,1], mu, error), paste0(dirname, name), row.names=FALSE, col.names=FALSE, sep=sep)
-}
-
-
-
-#' @name pMC.age
-#' @title Calculate C14 ages from pMC values.
-#' @description Calculate C14 ages from pMC values of radiocarbon dates.
-#' @details Post-bomb dates are often reported as pMC or percent modern carbon. Since Bacon expects radiocarbon ages,
-#'  this function can be used to calculate radiocarbon ages from pMC values. The reverse function is \link{age.pMC}.
-#' @param mn Reported mean of the pMC.
-#' @param sdev Reported error of the pMC.
-#' @param ratio Most modern-date values are reported against \code{100}. If it is against \code{1} instead, use \code{1} here.
-#' @param decimals Amount of decimals required for the radiocarbon age.
-#' @author Maarten Blaauw, J. Andres Christen
-#' @return Radiocarbon ages from pMC values. If pMC values are above 100\%, the resulting radiocarbon ages will be negative.
-#' @examples
-#'   pMC.age(110, 0.5) # a postbomb date, so with a negative 14C age
-#'   pMC.age(80, 0.5) # prebomb dates can also be calculated
-#'   pMC.age(.8, 0.005, 1) # pMC expressed against 1 (not against 100\%)
-#' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
-#' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
-#'  \url{https://projecteuclid.org/euclid.ba/1339616472}
-#' @export
-pMC.age <- function(mn, sdev, ratio=100, decimals=0) {
-  y <- -8033 * log(mn/ratio)
-  sdev <- y - -8033 * log((mn+sdev)/ratio)
-  round(c(y, sdev), decimals)
-}
-
-
-
-#' @name age.pMC
-#' @title Calculate pMC values from C14 ages
-#' @description Calculate pMC values from radiocarbon ages
-#' @details Post-bomb dates are often reported as pMC or percent modern carbon. Since Bacon expects radiocarbon ages,
-#' this function can be used to calculate pMC values from radiocarbon ages. The reverse function of \link{pMC.age}.
-#' @param mn Reported mean of the 14C age.
-#' @param sdev Reported error of the 14C age.
-#' @param ratio Most modern-date values are reported against \code{100}. If it is against \code{1} instead, use \code{1} here.
-#' @param decimals Amount of decimals required for the pMC value.
-#' @author Maarten Blaauw, J. Andres Christen
-#' @return pMC values from C14 ages.
-#' @examples
-#'   age.pMC(-2000, 20)
-#'   age.pMC(-2000, 20, 1)
-#' @seealso \url{http://www.qub.ac.uk/chrono/blaauw/manualBacon_2.3.pdf}
-#' @references
-#' Blaauw, M. and Christen, J.A., Flexible paleoclimate age-depth models using an autoregressive
-#' gamma process. Bayesian Anal. 6 (2011), no. 3, 457--474.
-#' \url{https://projecteuclid.org/euclid.ba/1339616472}
-#' @export
-age.pMC <- function(mn, sdev, ratio=100, decimals=3) {
-  y <- exp(-mn / 8033)
-  sdev <- y - exp(-(mn + sdev) / 8033)
-  signif(ratio*c(y, sdev), decimals)
-}
-
 
 
 #' @name add.dates
@@ -173,7 +46,7 @@ age.pMC <- function(mn, sdev, ratio=100, decimals=3) {
 #' @export
 add.dates <- function(mn, sdev, depth, cc=1, above=1e-6, ex=10, normal=TRUE, normalise=TRUE, t.a=3, t.b=4, age.res=100, times=20, col=rgb(1,0,0,.5), border=rgb(1,0,0,.5), rotate.axes=FALSE, mirror=TRUE, up=TRUE, BCAD=FALSE, pch=4) {
   if(cc > 0)
-    cc <- copyCalibrationCurve(cc)
+    cc <- IntCal::copyCalibrationCurve(cc)
 
   for(i in 1:length(mn)) {
     yrs <- seq(mn[i]-times*sdev[i], mn[i]+times*sdev[i], length=age.res)
@@ -233,7 +106,7 @@ add.dates <- function(mn, sdev, depth, cc=1, above=1e-6, ex=10, normal=TRUE, nor
 #' @param calheight Multiplier for the heights of the distributions of dates on the calendar scale. Defaults to \code{calheight=1}.
 #' @param mirror Plot the dates as 'blobs'. Set to \code{mirror=FALSE} to plot simple distributions.
 #' @param up Directions of distributions if they are plotted non-mirrored. Default \code{up=TRUE}.
-#' @param cutoff Avoid plotting very low probabilities of date distributions (default \code{cutoff=0.001}).
+#' @param cutoff Avoid plotting very low probabilities of date distributions (default \code{cutoff=0.1}).
 #' @param date.res Date distributions are plotted using \code{date.res=100} points by default.
 #' @param C14.col Colour of the calibrated distributions of the dates. Default is semi-transparent blue: \code{rgb(0,0,1,.35)}.
 #' @param C14.border Colours of the borders of calibrated 14C dates. Default is transparent dark blue: cal.col
@@ -258,8 +131,8 @@ add.dates <- function(mn, sdev, depth, cc=1, above=1e-6, ex=10, normal=TRUE, nor
 #' \url{https://projecteuclid.org/euclid.ba/1339616472}
 #' @export
 ### produce plots of the calibrated distributions
-calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FALSE, rev.d=FALSE, rev.age=FALSE, rev.yr=rev.age, age.lim=c(), yr.lim=age.lim, date.res=100, d.lab=c(), age.lab=c(), yr.lab=age.lab, height=15, calheight=1, mirror=TRUE, up=TRUE, cutoff=.001, C14.col=rgb(0,0,1,.5), C14.border=rgb(0,0,1,.75), cal.col=rgb(0,.5,.5,.5), cal.border=rgb(0,.5,.5,.75), dates.col=c(), slump.col=grey(0.8), new.plot=TRUE, plot.dists=TRUE, same.heights=FALSE, normalise.dists=TRUE) {
-  height <- length(set$d.min:set$d.max) * height/50
+calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FALSE, rev.d=FALSE, rev.age=FALSE, rev.yr=rev.age, age.lim=c(), yr.lim=age.lim, date.res=100, d.lab=c(), age.lab=c(), yr.lab=age.lab, height=30, calheight=1, mirror=TRUE, up=TRUE, cutoff=.1, C14.col=rgb(0,0,1,.5), C14.border=rgb(0,0,1,.75), cal.col=rgb(0,.5,.5,.5), cal.border=rgb(0,.5,.5,.75), dates.col=c(), slump.col=grey(0.8), new.plot=TRUE, plot.dists=TRUE, same.heights=FALSE, normalise.dists=TRUE) {
+  #height <- length(set$d.min:set$d.max) * height/50
   if(length(age.lim) == 0)
     lims <- c()
   for(i in 1:length(set$calib$probs))
@@ -302,17 +175,15 @@ calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FA
         cal[,2] <- cal[,2]/max(cal[,2])
       if(normalise.dists)
         cal[,2] <- cal[,2]/sum(cal[,2])
-      cal <- cal[cal[,2] >= cutoff,]
       cal[,2] <- height*cal[,2]
       if(ncol(set$dets) > 4 && set$dets[i,5] == 0) # cal BP date
         cal[,2] <- calheight*cal[,2]
-      cal <- approx(cal[,1], cal[,2], seq(min(cal[,1]), max(cal[,1]), length=100)) # tmp
 
       if(mirror)
-        pol <- cbind(c(d-cal$y, d+rev(cal$y)), c(cal$x, rev(cal$x))) else
+        pol <- cbind(c(d-cal[,2], d+rev(cal[,2])), c(cal[,1], rev(cal[,1]))) else
          if(up)
-           pol <- cbind(d-c(0, cal$y, 0), c(min(cal$x), cal$x, max(cal$x))) else
-             pol <- cbind(d+c(0, cal$y, 0), c(min(cal$x), cal$x, max(cal$x)))
+           pol <- cbind(d-c(0, cal[,2], 0), c(min(cal[,1]), cal[,1], max(cal[,1]))) else
+             pol <- cbind(d+c(0, cal[,2], 0), c(min(cal[,1]), cal[,1], max(cal[,1])))
       if(rotate.axes)
         pol <- cbind(pol[,2], pol[,1])
       if(ncol(set$dets)==4 && cc > 0 || (ncol(set$dets) > 4 && set$dets[i,5] > 0)) {
@@ -332,26 +203,26 @@ calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FA
 
 
 # calibrate C14 dates and calculate distributions for any calendar dates
-.bacon.calib <- function(dat, set=get('info'), date.res=100, normal=set$normal, t.a=set$t.a, t.b=set$t.b, delta.R=set$delta.R, delta.STD=set$delta.STD, ccdir="") {
+.bacon.calib <- function(dat, set=get('info'), date.res=100, cutoff=0.05, normal=set$normal, t.a=set$t.a, t.b=set$t.b, delta.R=set$delta.R, delta.STD=set$delta.STD, ccdir="") {
   # read in the curves
   if(set$cc1=="IntCal20" || set$cc1=="\"IntCal20\"")
-    cc1 <- read.table(paste(ccdir, "3Col_intcal20.14C",sep="")) else
-      cc1 <- read.csv(paste(ccdir, set$cc1, ".14C", sep=""), header=FALSE, skip=11)[,1:3]
+    cc1 <- read.table(paste0(ccdir, "3Col_intcal20.14C")) else
+      cc1 <- read.csv(paste0(ccdir, set$cc1, ".14C"), header=FALSE, skip=11)[,1:3]
   if(set$cc2=="Marine20" || set$cc2=="\"Marine20\"")
-    cc2 <- read.table(paste(ccdir, "3Col_marine20.14C",sep="")) else
-      cc2 <- read.csv(paste(ccdir, set$cc2, ".14C", sep=""), header=FALSE, skip=11)[,1:3]
+    cc2 <- read.table(paste0(ccdir, "3Col_marine20.14C")) else
+      cc2 <- read.csv(paste0(ccdir, set$cc2, ".14C"), header=FALSE, skip=11)[,1:3]
   if(set$cc3=="SHCal20" || set$cc3=="\"SHCal20\"")
-    cc3 <- read.table(paste(ccdir, "3Col_shcal20.14C",sep="")) else
-      cc3 <- read.csv(paste(ccdir, set$cc3, ".14C", sep=""), header=FALSE, skip=11)[,1:3]
+    cc3 <- read.table(paste0(ccdir, "3Col_shcal20.14C")) else
+      cc3 <- read.csv(paste0(ccdir, set$cc3, ".14C"), header=FALSE, skip=11)[,1:3]
   if(set$cc4=="ConstCal" || set$cc4=="\"ConstCal\"") cc4 <- NA else
     cc4 <- read.table(paste(ccdir, set$cc4, sep=""))[,1:3]
 
   if(set$postbomb != 0) {
-    if(set$postbomb==1) bomb <- read.table(paste(ccdir,"postbomb_NH1.14C", sep=""))[,1:3] else
-      if(set$postbomb==2) bomb <- read.table(paste(ccdir,"postbomb_NH2.14C", sep=""))[,1:3] else
-        if(set$postbomb==3) bomb <- read.table(paste(ccdir,"postbomb_NH3.14C", sep=""))[,1:3] else
-          if(set$postbomb==4) bomb <- read.table(paste(ccdir,"postbomb_SH1-2.14C", sep=""))[,1:3] else
-            if(set$postbomb==5) bomb <- read.table(paste(ccdir,"postbomb_SH3.14C", sep=""))[,1:3] else
+    if(set$postbomb==1) bomb <- read.table(paste0(ccdir,"postbomb_NH1.14C"))[,1:3] else
+      if(set$postbomb==2) bomb <- read.table(paste0(ccdir,"postbomb_NH2.14C"))[,1:3] else
+        if(set$postbomb==3) bomb <- read.table(paste0(ccdir,"postbomb_NH3.14C"))[,1:3] else
+          if(set$postbomb==4) bomb <- read.table(paste0(ccdir,"postbomb_SH1-2.14C"))[,1:3] else
+            if(set$postbomb==5) bomb <- read.table(paste0(ccdir,"postbomb_SH3.14C"))[,1:3] else
               stop("cannot find postbomb curve #", set$postbomb, " (use values of 1 to 5 only)", call.=FALSE)
       bomb.x <- seq(max(bomb[,1]), min(bomb[,1]), by=-.1) # interpolate
       bomb.y <- approx(bomb[,1], bomb[,2], bomb.x)$y
@@ -365,26 +236,24 @@ calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FA
   if(round(set$t.b-set$t.a) !=1)
     stop("t.b - t.a should always be 1, check the manual", call.=FALSE)
 
-  d.cal <- function(cc, rcmean, w2, t.a, t.b) {
+  d.cal <- function(cc, rcmean, w2, t.a, t.b) { # formula updated Oct 2020
     if(set$normal)
       cal <- cbind(cc[,1], dnorm(cc[,2], rcmean, sqrt(cc[,3]^2+w2))) else
-        cal <- cbind(cc[,1], (t.b+ ((rcmean-cc[,2])^2) / (2*(cc[,3]^2 + w2))) ^ (-1*(t.a+0.5))) # student-t
-    cal[,2] <- cal[,2]/sum(cal[,2])
-    if(length(which(cal[,2]>set$cutoff)) > 5) # ensure that also very precise dates get a range of probabilities
-      cal[which(cal[,2]>set$cutoff),] else {
-        calx <- seq(min(cal[,1]), max(cal[,1]), length=100)
-        caly <- approx(cal[,1], cal[,2], calx)$y
-        cbind(calx, caly/sum(caly), deparse.level = 0)
-      }
+        cal <- cbind(cc[,1], (t.b+ ((rcmean-cc[,2])^2) / (2*(cc[,3]^2 + w2))) ^ (-1*(t.a+0.5))) # student-t	   
+    cal[,2] <- cal[,2]/sum(cal[,2]) # normalise
+    these <- which(cal[,2] >= cutoff*max(cal[,2])) # keep those with values >% of the maximum height  
+    cal <- cal[these,]
+
+    calx <- seq(min(cal[,1]), max(cal[,1]), length=date.res)
+    caly <- approx(cal[,1], cal[,2], calx)$y
+    cbind(calx, caly/sum(caly), deparse.level = 0)
   }
 
   # now calibrate all dates
   calib <- list(d=dat[,4])
   if(ncol(dat)==4) { # only one type of dates (e.g., calBP, or all IntCal20 C14 dates)
     if(set$cc==0) {
-      x <- seq(min(dat[,2])-(5*max(dat[,3])), max(dat[,2])+(5*max(dat[,3])), by=5) # simplify, May 2019
-      if(length(x) > 100) # if too many resulting years, make 100 vals
-        x <- seq(min(dat[,2])-(5*max(dat[,3])), max(dat[,2])+(5*max(dat[,3])), length=100)
+      x <- seq(min(dat[,2])-(5*max(dat[,3])), max(dat[,2])+(5*max(dat[,3])), length=date.res)
       ccurve <- cbind(x, x, rep(0,length(x))) # dummy 1:1 curve
     } else {
         if(set$cc==1) ccurve <- cc1 else
@@ -398,14 +267,12 @@ calib.plot <- function(set=get('info'), BCAD=set$BCAD, cc=set$cc, rotate.axes=FA
       for(i in 1:nrow(dat)) {
         dets <- c(NA, as.numeric(dat[i,-1])) # the first column is not numeric
         if(dets[5]==0) {
-          x <- seq(dets[2]-(5*dets[3]), dets[2]+(5*dets[3]), by=5) # simplify, May 2019
-          if(length(x) < 5 || length(x) > 100) # if too many resulting years, make 100 vals
-            x <- seq(dets[2]-(5*dets[3]), dets[2]+(5*dets[3]), length=100)
+          x <- seq(dets[2]-(5*dets[3]), dets[2]+(5*dets[3]), length=date.res)
           ccurve <- cbind(x, x, rep(0,length(x))) # dummy 1:1 curve
         } else {
             if(dets[5]==1) ccurve <- cc1 else if(dets[5]==2) ccurve <- cc2 else
               if(dets[5]==3) ccurve <- cc3 else ccurve <- cc4
-              }
+            }
         delta.R <- set$delta.R; delta.STD <- set$delta.STD; t.a <- set$t.a; t.b <- set$t.b
         if(length(dets) >= 7 && dets[5] > 0) { # the user provided age offsets; only for C14 dates
           delta.R <- dets[6]
